# data.md 导出自语雀用于测试 react-markdown-render-integration

- 你可以将这个文件放到你的项目中通过动态导入测试或字符串形式测试 react-markdown-render-integration 支持的渲染语法

<h1 id="aUJbI">Menu 菜单组件</h1>
Menu 是一个功能完整的弹出式菜单组件，支持多级嵌套子菜单、自动定位和自定义样式。这个组件设计灵活，既支持声明式的子组件写法，也支持配置式的 JSON 写法，能够满足各种菜单场景的需求。

<h2 id="sjpGl">特性</h2>
+ ✅ 支持两种使用方式：配置式和子组件式
+ ✅ 支持自动定位，相对于触发元素的八个方向
+ ✅ 支持多级子菜单，最多支持两级嵌套
+ ✅ 支持自定义样式和主题
+ ✅ 支持自定义图标渲染
+ ✅ 提供完整的类型定义，TypeScript 友好

<h2 id="j1QW9">安装</h2>
该组件已集成在项目中，无需额外安装。位置：`src/components/global/Menu`

<h2 id="PY3IE">基本用法</h2>
<h3 id="W30Nj">方式 1：使用配置项创建菜单</h3>
```tsx
import React, { useRef, useState } from "react";
import { TouchableOpacity, View } from "react-native";
import { Ionicons } from "@expo/vector-icons";
import Menu, {
  MenuPosition,
  MenuItemConfig,
} from "../../components/global/Menu";

// 定义菜单配置
const MENU_CONFIG: MenuItemConfig[] = [
{
id: "history",
label: "历史记录",
icon: "time-outline",
onPress: "history",
},
{
id: "settings",
label: "设置",
icon: "settings-outline",
children: [
{
id: "account",
label: "账号设置",
icon: "person-outline",
onPress: "account",
},
{
id: "notification",
label: "通知设置",
icon: "notifications-outline",
onPress: "notification",
},
],
},
{
id: "about",
label: "关于",
icon: "information-circle-outline",
onPress: "about",
},
];

export default function MyComponent() {
const [menuVisible, setMenuVisible] = useState(false);
const buttonRef = useRef<View>(null);

const handleItemPress = (item: MenuItemConfig) => {
console.log(`选择了: ${item.id}`, item);
// 处理菜单项选择...
};

return (
<View>
<TouchableOpacity ref={buttonRef} onPress={() => setMenuVisible(true)}>
<Ionicons name="menu" size={24} color="black" />
</TouchableOpacity>

<Menu
visible={menuVisible}
onClose={() => setMenuVisible(false)}
position={MenuPosition.BOTTOM}
triggerRef={buttonRef}
items={MENU_CONFIG}
onItemPress={handleItemPress}
/>
</View>
);
}

````

<h3 id="jsjmU">方式 2：使用子组件创建菜单</h3>
```tsx
import React, { useRef, useState } from "react";
import { TouchableOpacity, View } from "react-native";
import { Ionicons } from "@expo/vector-icons";
import Menu, { MenuItem, MenuPosition } from "../../components/global/Menu";

export default function MyComponent() {
  const [menuVisible, setMenuVisible] = useState(false);
  const buttonRef = useRef<View>(null);

  return (
    <View>
      <TouchableOpacity ref={buttonRef} onPress={() => setMenuVisible(true)}>
        <Ionicons name="menu" size={24} color="black" />
      </TouchableOpacity>
      <Menu
        visible={menuVisible}
        onClose={() => setMenuVisible(false)}
        position={MenuPosition.BOTTOM}
        triggerRef={buttonRef}
      >
        <MenuItem
          label="历史记录"
          leftIcon={<Ionicons name="time-outline" size={20} color="#333" />}
          onPress={() => console.log("历史记录")}
        />
        <MenuItem
          label="设置"
          leftIcon={<Ionicons name="settings-outline" size={20} color="#333" />}
          onPress={() => console.log("设置")}
        />
        <MenuItem
          label="关于"
          leftIcon={
            <Ionicons
              name="information-circle-outline"
              size={20}
              color="#333"
            />
          }
          onPress={() => console.log("关于")}
        />
      </Menu>
    </View>
  );
}
````

<h2 id="puTBQ">Menu</h2>
<h3 id="HT1Fp">Menu API</h3>
| 属性 | 类型 | 默认值 | 描述 |
| --- | --- | --- | --- |
| visible | boolean | - | 是否显示菜单（必需） |
| onClose | () => void | - | 关闭菜单的回调函数（必需） |
| items | MenuItemConfig[] | - | 菜单项配置数组（配置式使用） |
| children | ReactNode | - | 子元素（子组件式使用） |
| position | MenuPosition | BOTTOM | 菜单相对于触发元素的位置 |
| triggerRef | React.RefObject | - | 触发元素的引用 |
| triggerLayout | Object | - | 触发元素的布局信息，可代替 triggerRef |
| offset | {x: number, y: number} | {x: 0, y: 0} | 菜单位置的偏移量 |
| width | number | 180 | 菜单宽度 |
| backgroundColor | string | "white" | 菜单背景色 |
| showShadow | boolean | true | 是否显示阴影 |
| closeOnSelect | boolean | true | 选择后是否自动关闭菜单 |
| iconColor | string | "#333" | 默认图标颜色 |
| renderIcon | IconRenderer | defaultIconRenderer | 自定义图标渲染函数 |
| onItemPress | (item: MenuItemConfig) => void | - | 菜单项点击回调 |
| containerStyle | StyleProp | - | 菜单容器样式 |
| itemStyle | StyleProp | - | 菜单项样式 |
| itemTextStyle | StyleProp | - | 菜单项文本样式 |

<h3 id="unyIC">MenuItem 组件</h3>
| 属性 | 类型 | 默认值 | 描述 |
| --- | --- | --- | --- |
| label | string | - | 菜单项显示的文本 |
| onPress | () => void | - | 点击回调函数 |
| disabled | boolean | false | 是否禁用此菜单项 |
| style | StyleProp | - | 菜单项容器样式 |
| textStyle | StyleProp | - | 菜单项文本样式 |
| color | string | "#333" | 文本颜色 |
| leftIcon | ReactNode | - | 左侧图标组件 |
| rightIcon | ReactNode | - | 右侧图标组件 |
| children | ReactNode | - | 自定义子元素 |

<h3 id="A7Yh7">MenuPosition 枚举</h3>
| 值 | 描述 |
| --- | --- |
| TOP | 在触发元素上方居中 |
| BOTTOM | 在触发元素下方居中 |
| LEFT | 在触发元素左侧居中 |
| RIGHT | 在触发元素右侧居中 |
| TOP_LEFT | 在触发元素上方，左对齐 |
| TOP_RIGHT | 在触发元素上方，右对齐 |
| BOTTOM_LEFT | 在触发元素下方，左对齐 |
| BOTTOM_RIGHT | 在触发元素下方，右对齐 |
| CUSTOM | the given position via `containerStyle` |

<h3 id="lxGC1">MenuItemConfig 接口</h3>

| 属性      | 类型             | 描述                     |
| --------- | ---------------- | ------------------------ | --------------------------------------- |
| id        | string           | 菜单项唯一标识符         |
| label     | string           | 菜单项显示的文本         |
| icon      | string           | 图标名称 (基于 Ionicons) |
| iconColor | string           | 图标颜色                 |
| color     | string           | 文本颜色                 |
| onPress   | string           | () => void               | 点击动作 - 可以是字符串标识符或回调函数 |
| children  | MenuItemConfig[] | 子菜单项 - 支持多级嵌套  |
| disabled  | boolean          | 是否禁用此菜单项         |

<h2 id="ey9qy">高级用法</h2>
<h3 id="MpaLS">自定义图标渲染</h3>
```tsx
import { FontAwesome } from "@expo/vector-icons";
import Menu, {
  IconRenderer,
  MenuItemConfig,
} from "../../components/global/Menu";

// 自定义图标渲染函数
const customIconRenderer: IconRenderer = (name, size, color, style) => (
<FontAwesome name={name} size={size} color={color} style={style} />
);

// 在 Menu 组件中使用

<Menu
  visible={menuVisible}
  onClose={() => setMenuVisible(false)}
  items={MENU_CONFIG}
  renderIcon={customIconRenderer}
/>;
```

<h3 id="HanIY">自定义菜单样式</h3>
```tsx
<Menu
  visible={menuVisible}
  onClose={() => setMenuVisible(false)}
  position={MenuPosition.BOTTOM}
  triggerRef={buttonRef}
  width={220}
  backgroundColor="#f8f9fa"
  containerStyle={{
    borderRadius: 12,
    borderWidth: 1,
    borderColor: "#e9ecef",
  }}
  itemStyle={{
    paddingVertical: 14,
    paddingHorizontal: 18,
  }}
  itemTextStyle={{
    fontSize: 16,
    fontWeight: "500",
  }}
  items={MENU_CONFIG}
/>
```

<h2 id="RstBk">注意事项</h2>
1. 确保为`triggerRef`提供一个有效的引用，以便组件能够正确计算菜单位置
2. 子菜单最多支持 2 级嵌套，超过 2 级的嵌套将不会显示
3. 使用`offset`属性可以微调菜单的位置
4. 配置式菜单与子组件式菜单不能混用 - 如果同时提供了`items`和`children`，`children`将优先显示

## 数学公式支持

行内公式：$E=mc^2$

块级公式：

$$
\frac{d}{dx}e^x = e^x
$$

## 任务列表

支持 GitHub 风格的任务列表：

```md
- [x] 已完成任务
- [ ] 未完成任务
```

## 以下是 React 常用的 API 分类整理表，涵盖核心功能、Hooks、组件 API 等：

- 用于测试渲染 api 表格

### **一、核心 API**

| API                           | 描述                                                    | 类型 |
| ----------------------------- | ------------------------------------------------------- | ---- |
| `React.createElement()`       | 创建 React 元素（JSX 底层调用）                         | 函数 |
| `React.Component`             | Class 组件的基类                                        | 类   |
| `React.PureComponent`         | 自动实现浅比较的 `shouldComponentUpdate` 的组件         | 类   |
| `React.memo(Component)`       | 函数组件的性能优化（类似 `PureComponent`）              | HOC  |
| `React.Fragment` / `<>...</>` | 包裹多个元素而不引入额外 DOM 节点                       | 组件 |
| `React.cloneElement()`        | 克隆并扩展 React 元素（如动态修改 props）               | 函数 |
| `React.Children`              | 操作 `props.children` 的工具方法（如 `map`, `forEach`） | 对象 |

---

### **二、Hooks（React 16.8+）**

| Hook                                     | 描述                                                        | 使用场景               |
| ---------------------------------------- | ----------------------------------------------------------- | ---------------------- |
| `useState(initialState)`                 | 管理组件内部状态                                            | 状态存储               |
| `useEffect(callback, deps)`              | 处理副作用（数据获取、订阅等）                              | 生命周期替代           |
| `useContext(Context)`                    | 获取 Context 的值                                           | 跨组件传值             |
| `useReducer(reducer, initialState)`      | 复杂状态逻辑管理（类似 Redux）                              | 状态集中处理           |
| `useCallback(fn, deps)`                  | 缓存函数，避免重复创建                                      | 性能优化               |
| `useMemo(value, deps)`                   | 缓存计算结果                                                | 性能优化               |
| `useRef(initialValue)`                   | 获取 DOM 引用或存储可变值                                   | 访问 DOM/持久化值      |
| `useImperativeHandle(ref, createHandle)` | 自定义暴露给父组件的实例方法                                | 配合 `forwardRef` 使用 |
| `useLayoutEffect`                        | 类似 `useEffect`，但同步执行（在 DOM 更新后、浏览器绘制前） | 需要直接操作 DOM 时    |

---

### **三、组件生命周期（Class 组件）**

| 方法                                            | 阶段   | 描述                           |
| ----------------------------------------------- | ------ | ------------------------------ |
| `componentDidMount()`                           | 挂载后 | DOM 初始化完成（适合请求数据） |
| `componentDidUpdate(prevProps, prevState)`      | 更新后 | 响应 props/state 变化          |
| `componentWillUnmount()`                        | 卸载前 | 清理定时器、订阅等             |
| `shouldComponentUpdate(nextProps, nextState)`   | 更新前 | 返回 `false` 阻止渲染          |
| `static getDerivedStateFromProps(props, state)` | 渲染前 | 根据 props 派生 state          |

---

### **四、Context API**

| API                                 | 描述                        |
| ----------------------------------- | --------------------------- |
| `React.createContext(defaultValue)` | 创建 Context 对象           |
| `Context.Provider`                  | 提供数据给子组件            |
| `Context.Consumer`                  | 消费 Context 的值（类组件） |

---

### **五、其他实用 API**

| API                         | 描述                        |
| --------------------------- | --------------------------- |
| `React.lazy()` + `Suspense` | 组件懒加载（动态导入）      |
| `React.forwardRef()`        | 转发 ref 到子组件           |
| `React.StrictMode`          | 严格模式（检测潜在问题）    |
| `ReactDOM.createPortal()`   | 将子节点渲染到 DOM 外的位置 |

---

### **六、常见工具库**

| API | 来源 | 描述 |
| --- | ---- | ---- |
